.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   examples
   contribute
   changelog

   autoapi/index

   Code Coverage <http://vpestel.pages.km3net.de/km3dia/coverage>
   Source (Git) <https://git.km3net.de/km3py/km3dia>



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
